@@ -96,10 +96,10 @@ private:
     Animation* writeMessage(const QString& text);
     Animation* writeText(const QString& text, bool fade = true);
     void displayMessages(const QList<QExplicitlySharedDataPointer<Message> >& msgs);
-    void playSound(int sound);
-    void onDeath();
     void setManPosition(const QPointF& p);
+    void updateBackground();
 protected:
+    bool event(QEvent *event) override;
     void mousePressEvent(QGraphicsSceneMouseEvent* e) override;
     void focusOutEvent(QFocusEvent*) override;
 public:
